@@ -312,6 +312,9 @@ ggit_diff_option_get_type (void)
 			{ GGIT_DIFF_MINIMAL,
 			  "GGIT_DIFF_MINIMAL",
 			  "minimal" },
+			{ GGIT_DIFF_SHOW_BINARY,
+			  "GGIT_DIFF_SHOW_BINARY",
+			  "show-binary" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_flags_register_static (
@@ -493,6 +496,50 @@ ggit_merge_file_favor_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_merge_file_flags_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_MERGE_FILE_DEFAULT,
+			  "GGIT_MERGE_FILE_DEFAULT",
+			  "default" },
+			{ GGIT_MERGE_FILE_STYLE_MERGE,
+			  "GGIT_MERGE_FILE_STYLE_MERGE",
+			  "style-merge" },
+			{ GGIT_MERGE_FILE_STYLE_DIFF3,
+			  "GGIT_MERGE_FILE_STYLE_DIFF3",
+			  "style-diff3" },
+			{ GGIT_MERGE_FILE_SIMPLIFY_ALNUM,
+			  "GGIT_MERGE_FILE_SIMPLIFY_ALNUM",
+			  "simplify-alnum" },
+			{ GGIT_MERGE_FILE_IGNORE_WHITESPACE,
+			  "GGIT_MERGE_FILE_IGNORE_WHITESPACE",
+			  "ignore-whitespace" },
+			{ GGIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE,
+			  "GGIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE",
+			  "ignore-whitespace-change" },
+			{ GGIT_MERGE_FILE_IGNORE_WHITESPACE_EOL,
+			  "GGIT_MERGE_FILE_IGNORE_WHITESPACE_EOL",
+			  "ignore-whitespace-eol" },
+			{ GGIT_MERGE_FILE_DIFF_PATIENCE,
+			  "GGIT_MERGE_FILE_DIFF_PATIENCE",
+			  "diff-patience" },
+			{ GGIT_MERGE_FILE_DIFF_MINIMAL,
+			  "GGIT_MERGE_FILE_DIFF_MINIMAL",
+			  "diff-minimal" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitMergeFileFlags"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_merge_tree_flags_get_type (void)
 {
@@ -513,6 +560,41 @@ ggit_merge_tree_flags_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_rebase_operation_type_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_REBASE_OPERATION_PICK,
+			  "GGIT_REBASE_OPERATION_PICK",
+			  "pick" },
+			{ GGIT_REBASE_OPERATION_REWORD,
+			  "GGIT_REBASE_OPERATION_REWORD",
+			  "reword" },
+			{ GGIT_REBASE_OPERATION_EDIT,
+			  "GGIT_REBASE_OPERATION_EDIT",
+			  "edit" },
+			{ GGIT_REBASE_OPERATION_SQUASH,
+			  "GGIT_REBASE_OPERATION_SQUASH",
+			  "squash" },
+			{ GGIT_REBASE_OPERATION_FIXUP,
+			  "GGIT_REBASE_OPERATION_FIXUP",
+			  "fixup" },
+			{ GGIT_REBASE_OPERATION_EXEC,
+			  "GGIT_REBASE_OPERATION_EXEC",
+			  "exec" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitRebaseOperationType"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_remote_download_tags_type_get_type (void)
 {
