@@ -83,6 +83,7 @@ ASSERT_ENUM (GGIT_DIFF_SHOW_UNTRACKED_CONTENT,     GIT_DIFF_SHOW_UNTRACKED_CONTE
 ASSERT_ENUM (GGIT_DIFF_SHOW_UNMODIFIED,            GIT_DIFF_SHOW_UNMODIFIED);
 ASSERT_ENUM (GGIT_DIFF_PATIENCE,                   GIT_DIFF_PATIENCE);
 ASSERT_ENUM (GGIT_DIFF_MINIMAL,                    GIT_DIFF_MINIMAL);
+ASSERT_ENUM (GGIT_DIFF_SHOW_BINARY,                GIT_DIFF_SHOW_BINARY);
 
 ASSERT_ENUM (GGIT_DIFF_FLAG_VALID_ID,   GIT_DIFF_FLAG_VALID_ID);
 ASSERT_ENUM (GGIT_DIFF_FLAG_BINARY,     GIT_DIFF_FLAG_BINARY);
@@ -122,6 +123,13 @@ ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_UNION, GIT_MERGE_FILE_FAVOR_UNION);
 
 ASSERT_ENUM (GGIT_MERGE_TREE_FIND_RENAMES, GIT_MERGE_TREE_FIND_RENAMES);
 
+ASSERT_ENUM (GGIT_REBASE_OPERATION_PICK, GIT_REBASE_OPERATION_PICK);
+ASSERT_ENUM (GGIT_REBASE_OPERATION_REWORD, GIT_REBASE_OPERATION_REWORD);
+ASSERT_ENUM (GGIT_REBASE_OPERATION_EDIT, GIT_REBASE_OPERATION_EDIT);
+ASSERT_ENUM (GGIT_REBASE_OPERATION_SQUASH, GIT_REBASE_OPERATION_SQUASH);
+ASSERT_ENUM (GGIT_REBASE_OPERATION_FIXUP, GIT_REBASE_OPERATION_FIXUP);
+ASSERT_ENUM (GGIT_REBASE_OPERATION_EXEC, GIT_REBASE_OPERATION_EXEC);
+
 ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED, GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED);
 ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_AUTO, GIT_REMOTE_DOWNLOAD_TAGS_AUTO);
 ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_NONE, GIT_REMOTE_DOWNLOAD_TAGS_NONE);
@@ -292,4 +300,14 @@ ASSERT_ENUM (GGIT_CLONE_LOCAL_LOCAL, GIT_CLONE_LOCAL);
 ASSERT_ENUM (GGIT_CLONE_LOCAL_NO_LOCAL, GIT_CLONE_NO_LOCAL);
 ASSERT_ENUM (GGIT_CLONE_LOCAL_NO_LINKS, GIT_CLONE_LOCAL_NO_LINKS);
 
+ASSERT_ENUM (GGIT_MERGE_FILE_DEFAULT, GIT_MERGE_FILE_DEFAULT);
+ASSERT_ENUM (GGIT_MERGE_FILE_STYLE_MERGE, GIT_MERGE_FILE_STYLE_MERGE);
+ASSERT_ENUM (GGIT_MERGE_FILE_STYLE_DIFF3, GIT_MERGE_FILE_STYLE_DIFF3);
+ASSERT_ENUM (GGIT_MERGE_FILE_SIMPLIFY_ALNUM, GIT_MERGE_FILE_SIMPLIFY_ALNUM);
+ASSERT_ENUM (GGIT_MERGE_FILE_IGNORE_WHITESPACE, GIT_MERGE_FILE_IGNORE_WHITESPACE);
+ASSERT_ENUM (GGIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE, GIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE);
+ASSERT_ENUM (GGIT_MERGE_FILE_IGNORE_WHITESPACE_EOL, GIT_MERGE_FILE_IGNORE_WHITESPACE_EOL);
+ASSERT_ENUM (GGIT_MERGE_FILE_DIFF_PATIENCE, GIT_MERGE_FILE_DIFF_PATIENCE);
+ASSERT_ENUM (GGIT_MERGE_FILE_DIFF_MINIMAL, GIT_MERGE_FILE_DIFF_MINIMAL);
+
 /* ex:set ts=8 noet: */
